<?php
/**
 * webpage.class.php provides access to our partials
 *
 * It defines a class, webpage, which gives access to our boilerplate partials which we 
 * re-use on every page.
 * 
 * @author David Argles <d.argles@gmx.com>
 * @version 22-10-2015, 10:28h
 * @copyright 2015 Haven Consulting
 */

  /**
   * webpage provides access to our templates
   *
   * Besides allowing us to load a particular template, it also allows us to change 
   * parameters in the file.
   * 
   */
  class webpage
  {
    /**
     * @access protected
     * @var class
     */
    protected $title = "Default tab title";
    protected $heading = "Default Website Heading";
    protected $tagline = "Default website description";
    protected $footer = "Default footer";
    protected $menu = array ("Page 1"=>"page1.php", "Page 2"=>"page2.php");
	
	  public function __construct()
    {
      if(@parse_ini_file("library/webpage.ini",true)){
        $iniFile = (object) parse_ini_file("webpage.ini",true);
        $this->heading = $iniFile->heading;
        $this->tagline = $iniFile->tagline;
        $this->footer = $iniFile->footer;
        $this->menu = (object) $iniFile->menu;
      }
      return;
    }
	     
    /**
     * render() allows us to change the css file used for a particular page
     * 
     * @param text filename (minus extension)
	   * @param array update information in [tag] => [value] format
     * @return The updated template text
     */
    public function render($file, $substitutions = array()) 
  	{
      // We'll need to know the filename of the current page
      $thispage = substr(strrchr($_SERVER['PHP_SELF'],"/"),1);
      // Check that the template exists
      $filename = "library/$file.html";
      if(!file_exists($filename)) throw new Exception("Could not find template $file in $filename.");
      // Load the template
      $template = file_get_contents($filename);
      // Insert simple values from ini file into the substitions list      
      $substitutions = $substitutions + array("heading" => $this->heading, "tagline" => $this->tagline, 
        "footer" => $this->footer);
      // Now add the menu entries from the ini file
      //Initialise the menu variable
      $menu = "\n";
      // Iterate through the list of the varous pages' names and related filenames
      foreach($this->menu as $name => $page)
      {
	  	if($thispage==$page)
	  	{
	  	  // We've found the current page name, so record it in $title
	  	  $this->title = $name;
		  // And choose the "selected" class for our menu link...
	  	  $menu = $menu."      <a href=\"$page\" class=\"selected\">$name</a>\n";
      }
      // ...otherwise, just use the normal menu link
      else $menu = $menu."      <a href=\"$page\">$name</a>\n";
      } 
      // Now add the page title and the menu links to the substitutions list
      $substitutions = $substitutions + array("title" => $this->title, "menu" => $menu);
      // Substitute any placeholders
      foreach($substitutions as $key => $replacement) $template = str_replace('{{'.$key.'}}', $replacement, $template); 
      // Send back the result
      return $template;
    }
  }
/**---------------------------------------------
 *             End of Code
 *----------------------------------------------
 */
?>
